@@ -1,5 +1,5 @@
 .onLoad <- function(lib, pkg) {
-    pkgList <- c("digest", "filehash", "stashR")
+    pkgList <- c("filehash", "stashR")
     
     for(pkg in pkgList) {
         if(!require(pkg, quietly = TRUE, character.only = TRUE))
